@@ -22,6 +22,7 @@ from clusterondemand.images.find import CODImage, ImageSource
 from clusterondemand.images.find import findimages_ns as common_findimages_ns
 from clusterondemandconfig import ConfigNamespace, config
 
+from .azure_actions.storage import StorageAction
 from .azure_actions.throttle import unt
 
 log = logging.getLogger("cluster-on-demand")
@@ -67,43 +68,61 @@ class AzureImageSource(ImageSource):
         )
 
     def _iter_from_source(self):
-        for url in config["container_url"]:
-            container_client = ContainerClient.from_container_url(url)
-            for blob in unt(container_client.list_blobs):
-                try:
-                    cod_image = make_cod_image_from_azure(blob, url)
-                except CannotParseImageName as e:
-                    # This is parsing names of public images, someone could even upload some bogus name
-                    # to break our code. So we just ignore if we can't parse it
-                    # Other exception can blow up
-                    log.debug(e)
-                else:
-                    yield cod_image
+        if self.uuids:
+            for vhd_url in self.uuids:  # In case of COD-Azure, UUID is a URL
+                blob = StorageAction.get_blob_properties(vhd_url)
+                yield make_cod_image_from_azure(blob, vhd_url, allow_custom_images=True)
+        else:
+            for url in config["container_url"]:
+                container_client = ContainerClient.from_container_url(url)
+                for blob in unt(container_client.list_blobs):
+                    try:
+                        cod_image = make_cod_image_from_azure(blob, url + blob.name)
+                    except CannotParseImageName as e:
+                        # This is parsing names of public images, someone could even upload some bogus name
+                        # to break our code. So we just ignore if we can't parse it
+                        # Other exception can blow up
+                        log.debug(e)
+                    else:
+                        yield cod_image
 
 
-def make_cod_image_from_azure(blob, container_url):
+def make_cod_image_from_azure(blob, vhd_url, allow_custom_images=False):
+    """
+    Convert Azure's image information to COD image object
+
+    :param blob: Azure's blob properties
+    :param vhd_url: url to vhd image
+    :param allow_custom_images: allow non-Bright images
+    :return: CODImage object for specified image
+    """
+    additional_params = {}
     match = re.match(IMAGE_NAME_REGEX_AZURE, blob.name)
-    if not match:
+    if match:
+        name, version, distribution, revision = match.groups()
+
+        # Prior to CM-35092, we didn't have the distro in the image name
+        # So some of them don't have it.
+        # We just set as "centos" without specifying version
+        if not distribution:
+            distribution = "centos"
+
+        additional_params = {
+            "name": name,
+            "version": version,
+            "distro": distribution,
+            "revision": int(revision),
+            "id": f"{distribution}-{version}",
+        }
+    elif not allow_custom_images:
         raise CannotParseImageName(f"Cannot parse image name {blob.name}")
 
-    name, version, distribution, revision = match.groups()
-
-    # Prior to CM-35092, we didn't have the distro in the image name
-    # So some of them don't have it.
-    # We just set as "centos" without specifying version
-    if not distribution:
-        distribution = "centos"
-
     return CODImage(
-        name=name,
-        id=f"{distribution}-{version}",
-        uuid=container_url + blob.name,
-        revision=int(revision),
-        version=version,
-        distro=distribution if distribution else "",
+        uuid=vhd_url,
         size=blob.size,
         created_at=blob.creation_time,
         image_visibility="N/A",
         type="headnode",
         cloud_type="azure",
+        **additional_params,
     )
